"""


"""
class Phewas:
	
	"""
	This is the object that is used to run Phewas.

	Checks the validity of arguments such as:
	* Valid Phewas file structure
	* Valid values for the arguments passed

	Allows for option such as:
	* Age-matching and control
	* Matching and control by other criteria
	"""
	
	def __init__(self):
		"""
		
		
		"""
		pass
	
